local skinTable = {}

local function newskin(skin_name, skin_dir)
	skin_name = tostring(skin_name)
	if skin_name == "nil" then
		return
	end
	skin_dir = tostring(skin_dir)
	
	lib.log_error("Reskin: Registering " .. (skin_name) .. " as a default interface skin")
	skinTable[#skinTable + 1] = {
		name = skin_name,
		dir = skin_dir,
	}
end

local function get_skins()
	local rettable = {}
	for k, v in ipairs(skinTable) do
		rettable[#rettable + 1] = v.name
	end
	
	return rettable
end

local function get_cur()
	for k, v in ipairs(skinTable) do
		if v.dir == IMAGE_DIR then
			return v.name
		end
	end
	
	return "_unregistered skin"
end

local function get_skin_dir(skin)
	for k, v in ipairs(skinTable) do
		if v.name == skin then
			return v.dir
		end
	end
	return false
end

local function selSkinDiag()
	local selIndex = 1
	
	local preview_thumb = IMAGE_DIR .. "/preview.png"
	local preview_pane = iup.label {
		title = "",
		image = preview_thumb,
		size = "256x256",
	}
	local function update_preview()
		preview_thumb = skinTable[selIndex].dir .. "/preview.png"
		
		if skinTable[selIndex].name == "Default Platinum" then
			preview_thumb = "plugins/Reskin/platinum_preview.png"
		elseif skinTable[selIndex].name == "Default Blue" then
			preview_thumb = "plugins/Reskin/blue_preview.png"
		end
		
		if not gksys.IsExist(preview_thumb) then
			preview_thumb = "plugins/Reskin/preview.png"
		end
		preview_pane.image = preview_thumb
		iup.Refresh(preview_pane)
	end
	
	update_preview()
	
	local skinlist = iup.list {
		dropdown = "YES",
		action = function(self, name, index, cval)
			if cval == 1 then
				selIndex = index
				update_preview()
			end
		end,
	}
	
	for k, v in ipairs(skinTable) do
		skinlist[k] = v.name
	end
	
	local newUIToggle = iup.stationtoggle {
		title = "",
		value = "",
		action = function(self)
			if self.value == "ON" then
				gkini.WriteInt("Vendetta", "usenewui", 1)
			else
				gkini.WriteInt("Vendetta", "usenewui", 0)
			end
		end,
	}
	
	if gkini.ReadInt("Vendetta", "usenewui") == 0 then
		newUIToggle.value = "OFF"
	else
		newUIToggle.value = "ON"
	end
	
	local diag = iup.dialog {
		topmost = "YES",
		fullscreen = "YES",
		bgcolor = "0 0 0 200 *",
		iup.hbox {
			iup.fill { },
			iup.vbox {
				iup.fill { },
				iup.label {
					title = "Reskin",
					font = Font.H1,
				},
				iup.frame {
					iup.vbox {
						iup.label {
							title = "Select a skin to load from the list below:",
						},
						iup.fill {
							size = "%2",
						},
						skinlist,
						iup.fill {
							size = "%1",
						},
						iup.hbox {
							iup.fill { },
							preview_pane,
							iup.fill { },
						},
						iup.hbox {
							iup.fill { },
							iup.label {
								title = "Use 'Angular' UI: ",
							},
							newUIToggle,
						},
						iup.hbox {
							iup.fill { },
							iup.stationbutton {
								title = "Load selected skin",
								action = function()
									gkini.WriteString("Vendetta", "skin", skinTable[selIndex].dir)
									ReloadInterface()
								end,
							},
							iup.stationbutton {
								title = "Cancel",
								action = function(self)
									HideDialog(iup.GetDialog(self))
									iup.Destroy(iup.GetDialog(self))
								end,
							},
						},
					},
				},
				iup.fill { },
			},
			iup.fill { },
		},
	}
	diag:map()
	diag:show()
end

lib.set_class("reskin", "2.1.0", {register = newskin, open = selSkinDiag, getall = get_skins, getpath = get_skin_dir, getcurrent = get_cur})
--lib.lockclass("reskin", 2, lib.generate_key())

--these are here to ensure they are at the top of the skin editor
newskin("Default Platinum", "skins/platinum/")
newskin("Default Blue", "images/station/")




lib.require({{name = "neomgr", version = "0"}}, function()
	lib.execute("neomgr", "0", "add_option", iup.button {
		title = "Reskin",
		action = function()
			selSkinDiag()
		end,
	})
end)

lib.require({{name = "MultiUI", version = "5"}}, function()
	--still working on that API
end)